# Explanation

<!-- diataxis: explanation -->

Concepts, architecture, and design decisions behind zodb-pgjsonb.
Read these to deepen your understanding of how and why the system works the way it does.

```{toctree}
---
maxdepth: 2
titlesonly: true
---
architecture
why-postgresql-jsonb
performance
security
```
